---
title: Starsim models
jupyter: python3
---


The Starsim framework serves as a centralized "hub" for storing anything that is typically required to model the spread of diseases among agents. This includes representations of networks, diseases, populations, demographics, interventions, and products, and logic for connecting all of these things together and simulating their interactions over time. 

Specific models that have been created using the Starsim framework are kept in their own separate repositories. As of May 2025, Starsim's models include the following models:

| Model | Status | Description |
|-------|--------|------------|
| [HPVsim](https://hpvsim.org) | Stable | Human papillomavirus (HPV) and cervical cancer |
| [FPsim](https://fpsim.org) | Stable | Family planning and reproductive health |
| [STIsim](https://github.com/starsimhub/stisim) | Beta | Sexually transmitted infections, including HIV, bacterial vaginosis, chlamydia, gonorrhea, syphilis, and trichomoniasis |
| [Rotasim](https://github.com/starsimhub/rotasim) | Pre-release | Rotavirus, with a focus on genetic diversity |
| [PHCsim](https://github.com/starsimhub/phcsim) | Pre-release | Primary health care and health systems |
| [MIGHTI](https://github.com/starsimhub/mighti) | Pre-release | Model of Inter-Generational Health, Transmission, and Interventions (HIV and other comorbidities) |
| [TBsim](https://github.com/starsimhub/tbsim) | Pre-release | Tuberculosis, including malnutrition |
| [RVFsim](https://github.com/starsimhub/RVFSim) | Pre-release | Rift valley fever in cattle |
| Typhoidsim | Pre-release | Typhoid, including environmental transmission |

*If you've developed a model and want it included in this list, please [get in touch](mailto:info@starsim.org).*

One of the strengths of Starsim is that all of these models are inter-compatible. For example, an HIV-TB coinfection model can be created by combining the HIV module from STIsim and the TB module from TBsim.

Note: the Starsim suite also includes [Covasim](https://github.com/institutefordiseasemodeling/covasim) (for modeling COVID-19). Covasim is built on the same principles as Starsim, but unlike the above tools, it is a separate codebase and is not inter-operable with the other models.


